@@ -1,8 +1,5 @@
-#!/usr/bin/perl
-
 package HTTP::Engine::Interface::Test::ResponseWriter;
 use Moose;
-use HTTP::Engine::ResponseFinalizer;
 
 with qw(HTTP::Engine::Role::ResponseWriter);
 
@@ -14,7 +11,6 @@ has '_response' => (
 sub finalize {
     my ( $self, $req, $res ) = @_;
 
-    HTTP::Engine::ResponseFinalizer->finalize($req => $res);
     $self->_response($res->as_http_response);
 }
 
@@ -25,22 +21,8 @@ sub get_response {
     return $res;
 }
 
+sub write       { die "dummy" }
+sub output_body { die "dummy" }
+
 __PACKAGE__
 
-__END__
-
-=pod
-
-=head1 NAME
-
-HTTP::Engine::Interface::Test::ResponseWriter - 
-
-=head1 SYNOPSIS
-
-	use HTTP::Engine::Interface::Test::ResponseWriter;
-
-=head1 DESCRIPTION
-
-=cut
-
-
