@@ -13,14 +13,9 @@ use URI::QueryParam;
 
 # this object constructs all our lazy fields for us
 has request_builder => (
-    does => "HTTP::Engine::Role::RequestBuilder",
-    is   => "rw",
-    # handles ...
-    # takes_self => 1, # add this to Moose
-    default => sub { # FIXME deprecate the default
-        require HTTP::Engine::RequestBuilder::Dummy;
-        HTTP::Engine::RequestBuilder::Dummy->new;
-    }
+    does     => "HTTP::Engine::Role::RequestBuilder",
+    is       => "rw",
+    required => 1,
 );
 
 sub BUILD {
@@ -41,14 +36,10 @@ has _builder_params => (
 
 has _connection => (
     is => "ro",
-    lazy_build => 1,
+    isa => 'HashRef',
+    required => 1,
 );
 
-sub _build__connection {
-    my $self = shift;
-    $self->request_builder->_build_connection($self);
-}
-
 has "_read_state" => (
     is => "rw",
     lazy_build => 1,
@@ -246,6 +237,7 @@ sub cookie {
         return undef unless exists $self->cookies->{$name}; ## no critic.
         return $self->cookies->{$name};
     }
+    return;
 }
 
 sub param {
@@ -266,7 +258,7 @@ sub param {
               ? ( $self->parameters->{$param} )
                   : $self->parameters->{$param};
         }
-    } elsif (@_ > 1) {
+    } else {
         my $field = shift;
         $self->parameters->{$field} = [@_];
     }
@@ -290,9 +282,7 @@ sub upload {
               ? ( $self->uploads->{$upload} )
           : $self->uploads->{$upload};
         }
-    }
-
-    if (@_ > 1) {
+    } else {
         while ( my($field, $upload) = splice(@_, 0, 2) ) {
             if ( exists $self->uploads->{$field} ) {
                 for ( $self->uploads->{$field} ) {
