@@ -13,18 +13,19 @@ sub finalize {
     $res->protocol( $req->protocol ) unless $res->protocol;
 
     # Content-Length
-    $res->content_length(0);
     if ($res->body) {
         # get the length from a filehandle
-        if (Scalar::Util::blessed($res->body) && $res->body->can('read') or ref($res->body) eq 'GLOB') {
-            if (my $stat = File::stat::stat $res->body) {
+        if ((Scalar::Util::blessed($res->body) && $res->body->can('read')) || (ref($res->body) eq 'GLOB')) {
+            if (my $stat = eval { File::stat::stat $res->body }) {
                 $res->content_length($stat->size);
             } else {
-                warn 'Serving filehandle without a content-length';
+                die 'Serving filehandle without a content-length';
             }
         } else {
             $res->content_length(bytes::length($res->body));
         }
+    } else {
+        $res->content_length(0);
     }
 
     # Errors
@@ -38,6 +39,11 @@ sub finalize {
 
     $class->_finalize_cookies($res);
 
+    # HTTP/1.1's default Connection: close
+    if ($res->protocol && $res->protocol =~ m!1\.1! && !!!$res->header('Connection')) {
+        $res->header( Connection => 'close' );
+    }
+
     $res->body('') if $req->method eq 'HEAD';
 }
 
@@ -55,7 +61,7 @@ sub _finalize_cookies  {
                 -expires => $val->{expires},
                 -domain  => $val->{domain},
                 -path    => $val->{path},
-                -secure  => $val->{secure} || 0
+                -secure  => ($val->{secure} || 0)
             )
         );
 
