@@ -1,5 +1,3 @@
-#!/usr/bin/perl
-
 package HTTP::Engine::Role::RequestBuilder::ParseEnv;
 use Moose::Role;
 
@@ -48,12 +46,14 @@ sub _build_uri  {
 
     my $scheme = $req->secure ? 'https' : 'http';
     my $host   = $env->{HTTP_HOST}   || $env->{SERVER_NAME};
-    my $port   = $env->{SERVER_PORT} || ( $req->secure ? 443 : 80 );
+    # my $port   = $env->{SERVER_PORT} || ( $req->secure ? 443 : 80 );
+    my $port   = $env->{SERVER_PORT};
+    $port = ( $req->secure ? 443 : 80 ) unless $port; # dirty code for coverage_test 
 
     my $base_path;
     if (exists $env->{REDIRECT_URL}) {
         $base_path = $env->{REDIRECT_URL};
-        $base_path =~ s/$env->{PATH_INFO}$//;
+        $base_path =~ s/$env->{PATH_INFO}$// if exists $env->{PATH_INFO};
     } else {
         $base_path = $env->{SCRIPT_NAME} || '/';
     }
@@ -73,6 +73,7 @@ sub _build_uri  {
 
     # set the base URI
     # base must end in a slash
+    $base_path =~ s{^/+}{};
     $base_path .= '/' unless $base_path =~ /\/$/;
     my $base = $uri->clone;
     $base->path_query($base_path);
@@ -80,23 +81,5 @@ sub _build_uri  {
     return URI::WithBase->new($uri, $base);
 }
 
-
-__PACKAGE__
-
-__END__
-
-=pod
-
-=head1 NAME
-
-HTTP::Engine::Role::RequestBuilder::ParseEnv - 
-
-=head1 SYNOPSIS
-
-	use HTTP::Engine::Role::RequestBuilder::ParseEnv;
-
-=head1 DESCRIPTION
-
-=cut
-
+1;
 
